@@ -17,6 +17,8 @@ import (
 
 	// SQLite3 driver.
 	_ "github.com/mattn/go-sqlite3"
+	// SQlite3 extension library.
+	sqlite3_stdlib "github.com/multiprocessio/go-sqlite3-stdlib"
 )
 
 var (
@@ -53,6 +55,12 @@ type DB struct {
 	importCount int
 }
 
+func init() {
+	// Enable sqlite3 extensions.
+	// It can be used by setting the driver to "sqlite3_ext".
+	sqlite3_stdlib.Register("sqlite3_ext")
+}
+
 // Connect is connects to the database.
 // Currently supported drivers are sqlite3, mysql, postgres.
 // Set quote character and maxBulk depending on the driver type.
@@ -70,7 +78,7 @@ func Connect(driver, dsn string) (*DB, error) {
 	debug.Printf("driver: %s, dsn: %s", driver, dsn)
 
 	switch driver {
-	case "sqlite3":
+	case "sqlite3", "sqlite3_ext":
 		db.quote = "`"
 		db.maxBulk = 500
 	case "mysql":
@@ -139,8 +147,8 @@ func (db *DB) queryCreateTable(tableName string, columnNames []string, columnTyp
 type importTable struct {
 	tableName string
 	columns   []string
-	maxCap    int
 	row       []interface{}
+	maxCap    int
 	lastCount int
 	count     int
 }
@@ -376,6 +384,9 @@ func queryInsert(table *importTable) string {
 // QuotedName returns the table name quoted.
 // Returns as is, if already quoted.
 func (db *DB) QuotedName(orgName string) string {
+	if orgName == "" {
+		return ""
+	}
 	if orgName[0] == db.quote[0] {
 		return orgName
 	}
