@@ -3,7 +3,6 @@ package trdsql
 import (
 	"bytes"
 	"io"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"strconv"
@@ -541,7 +540,7 @@ func TestOutFormatRun(t *testing.T) {
 			t.Errorf("trdsql error. %s", err)
 		}
 		got := outStream.String()
-		golden, err := ioutil.ReadFile(filepath.Join("testdata", c.result+".golden"))
+		golden, err := os.ReadFile(filepath.Join("testdata", c.result+".golden"))
 		if err != nil {
 			t.Fatalf("failed reading .golden: %s", err)
 		}
@@ -720,6 +719,7 @@ func TestFormat_String(t *testing.T) {
 }
 
 func benchmarkFormat(b *testing.B, format Format) {
+	b.Helper()
 	sql := "SELECT * FROM " + filepath.Join(dataDir, "KEN_ALL.CSV")
 	outStream := new(bytes.Buffer)
 	importer := NewImporter(InFormat(GUESS))
@@ -732,8 +732,7 @@ func benchmarkFormat(b *testing.B, format Format) {
 	trd := NewTRDSQL(importer, exporter)
 	trd.Driver = "sqlite3"
 	trd.Dsn = ""
-	err := trd.Exec(sql)
-	if err != nil {
+	if err := trd.Exec(sql); err != nil {
 		b.Fatal(err)
 	}
 }
